==> 0.0.23.tar.gz: lib/src/widgets/story_widget.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_story/src/widgets/story_image_widget.dart';
import 'package:ocg_story/src/widgets/story_video_widget.dart';
import 'package:video_player/video_player.dart';

enum StoryAssetType { Asset, File, Network }

class StoryWidget extends StatefulWidget {
  final AnimationController animationController;
  final List<StoryBackground> data;
  final Widget lineHeader;
  final Widget lineBottom;
  final Widget child;
  final StoryAssetType type;
  final Function(int page) onPageChanged;
  final Duration imageDuration;
  final Duration videoDuration;

  StoryWidget({
    Key key,
    this.data,
    this.lineHeader,
    this.lineBottom,
    this.imageDuration,
    this.videoDuration,
    this.type = StoryAssetType.Network,
    this.animationController,
    this.onPageChanged,
    this.child,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _StoryScreenState();
}

class _StoryScreenState extends State<StoryWidget>
    with TickerProviderStateMixin<StoryWidget> {
  AnimationController controller;
  int current = 0;
  bool isLoaded = true;
  VideoPlayerController videoPlayerController;

  @override
  void initState() {
    super.initState();
    current = 0;
    controller = widget.animationController ??
        AnimationController(vsync: this, duration: Duration(seconds: 3));
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    controller.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        jumpToNext();
      }
    });
  }

  double lastValue = 0.0;

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.black,
      child: GestureDetector(
        onLongPress: () {
          lastValue = controller.value;
          controller.stop(canceled: false);
          if (widget.data[current] is StoryVideo &&
              videoPlayerController != null) {
            videoPlayerController.pause();
          }
        },
        onLongPressEnd: (val) {
          if (widget.data[current] is StoryVideo &&
              videoPlayerController != null) {
            controller.value = lastValue;
            controller.animateTo(1,
                duration: videoPlayerController.value.duration);
            videoPlayerController.play();
          } else {
            controller.forward(from: lastValue);
          }
          lastValue = 0.0;
        },
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            widget.data[current].type == StoryType.video
                ? FittedBox(
                    fit: BoxFit.cover,
                    child: StoryVideoWidget(
                        type: widget.type,
                        url: (widget.data[current] as StoryVideo).url,
                        onLoaded: (val, videoController) {
                          if (videoController == null) {
                            return;
                          }
                          videoPlayerController = videoController;
                          controller.value = 0;
                          if (widget.videoDuration == null) {
                            controller.animateTo(1.0,
                                duration: videoController.value.duration);
                          } else {
                            controller.animateTo(1.0,
                                duration: widget.videoDuration);
                          }
                        },
                        onCompleted: () {}),
                  )
                : widget.data[current].type == StoryType.image
                    ? StoryImageWidget(
                        image: (widget.data[current] as StoryImage).url,
                        onLoaded: (val) async {
                          controller.value = 0;
                          if (widget.imageDuration == null) {
                            controller.animateTo(
                              1.0,
                            );
                          } else {
                            controller.animateTo(1.0,
                                duration: widget.imageDuration);
                          }
                        },
                      )
                    : Container(),
            Row(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Expanded(
                  child: GestureDetector(
                    child: Container(
                      color: Colors.black.withOpacity(0.01),
                      height: MediaQuery.of(context).size.height,
                    ),
                    onTap: () {
                      jumpToPrevious();
                    },
                  ),
                ),
                Expanded(
                  child: GestureDetector(
                    onTap: () {
                      jumpToNext();
                    },
                    child: Container(
                      height: MediaQuery.of(context).size.height,
                      color: Colors.transparent,
                    ),
                  ),
                )
              ],
            ),
            Container(
              padding: EdgeInsets.symmetric(vertical: 16.0, horizontal: 12),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: <Widget>[
                  widget.lineHeader ?? Container(),
                  Expanded(child: widget.child ?? Container()),
                  widget.lineBottom ?? Container()
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  // @override
  // void didUpdateWidget(StoryWidget oldWidget) {
  //   if (oldWidget.page != widget.page) {
  //     current = widget.page;
  //     controller.value = 0;
  //     controller.forward(from: 0);
  //     setState(() {});
  //   }
  //   super.didUpdateWidget(oldWidget);
  // }

  void jumpToPrevious() {
    if (current > 0) {
      current--;
      controller.value = 0;
      widget.onPageChanged(current);
    } else if (current == 0) {
      widget.onPageChanged(current - 1);
    }
    setState(() {});
  }

  void jumpToNext() {
    if (current >= widget.data.length - 1) {
      widget.onPageChanged(current + 1);
      return;
    }
    current++;
    widget.onPageChanged(current);
    if (mounted) setState(() {});
  }

  @override
  void dispose() {
    if (widget.animationController != null) controller.dispose();
    super.dispose();
  }
}

==> 0.0.27.tar.gz: lib/src/widgets/story_widget.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_story/src/widgets/story_image_widget.dart';
import 'package:ocg_story/src/widgets/story_video_widget.dart';
import 'package:video_player/video_player.dart';

enum StoryAssetType { Asset, File, Network }

class StoryWidget extends StatefulWidget {
  final AnimationController animationController;
  final List<StoryBackground> data;
  final Widget lineHeader;
  final Widget lineBottom;
  final Widget child;
  final StoryAssetType type;
  final Function(int page) onPageChanged;
  final Duration imageDuration;
  final Duration videoDuration;

  StoryWidget({
    Key key,
    this.data,
    this.lineHeader,
    this.lineBottom,
    this.imageDuration,
    this.videoDuration,
    this.type = StoryAssetType.Network,
    this.animationController,
    this.onPageChanged,
    this.child,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _StoryScreenState();
}

class _StoryScreenState extends State<StoryWidget>
    with TickerProviderStateMixin<StoryWidget> {
  AnimationController controller;
  int current = 0;
  bool isLoaded = true;
  VideoPlayerController videoPlayerController;

  @override
  void initState() {
    super.initState();
    current = 0;
    controller = widget.animationController ??
        AnimationController(vsync: this, duration: Duration(seconds: 3));
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    controller.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        jumpToNext();
      }
    });
  }

  double lastValue = 0.0;

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.black,
      child: GestureDetector(
        onLongPress: () {
          lastValue = controller.value;
          controller.stop(canceled: false);
          if (widget.data[current] is StoryVideo &&
              videoPlayerController != null) {
            videoPlayerController.pause();
          }
        },
        onLongPressEnd: (val) {
          if (widget.data[current] is StoryVideo &&
              videoPlayerController != null) {
            controller.value = lastValue;
            controller.animateTo(1,
                duration: videoPlayerController.value.duration);
            videoPlayerController.play();
          } else {
            controller.forward(from: lastValue);
          }
          lastValue = 0.0;
        },
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            widget.data[current].type == StoryType.video
                ? FittedBox(
                    fit: BoxFit.cover,
                    child: StoryVideoWidget(
                        type: widget.type,
                        url: (widget.data[current] as StoryVideo).url,
                        onLoaded: (val, videoController) {
                          if (videoController == null) {
                            return;
                          }
                          videoPlayerController = videoController;
                          controller.value = 0;
                          if (widget.videoDuration == null) {
                            controller.animateTo(1.0,
                                duration: videoController.value.duration);
                          } else {
                            controller.animateTo(1.0,
                                duration: widget.videoDuration);
                          }
                        },
                        onCompleted: () {}),
                  )
                : widget.data[current].type == StoryType.image
                    ? StoryImageWidget(
                        image: (widget.data[current] as StoryImage).url,
                        onLoaded: (val) async {
                          controller.value = 0;
                          if (widget.imageDuration == null) {
                            controller.animateTo(
                              1.0,
                            );
                          } else {
                            controller.animateTo(1.0,
                                duration: widget.imageDuration);
                          }
                        },
                      )
                    : Container(),
            Row(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Expanded(
                  child: GestureDetector(
                    child: Container(
                      color: Colors.black.withOpacity(0.01),
                      height: MediaQuery.of(context).size.height,
                    ),
                    onTap: () {
                      jumpToPrevious();
                    },
                  ),
                ),
                Expanded(
                  child: GestureDetector(
                    onTap: () {
                      jumpToNext();
                    },
                    child: Container(
                      height: MediaQuery.of(context).size.height,
                      color: Colors.transparent,
                    ),
                  ),
                )
              ],
            ),
            Container(
              padding: EdgeInsets.symmetric(vertical: 16.0, horizontal: 12),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: <Widget>[
                  widget.lineHeader ?? Container(),
                  Expanded(child: widget.child ?? Container()),
                  widget.lineBottom ?? Container()
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  // @override
  // void didUpdateWidget(StoryWidget oldWidget) {
  //   if (oldWidget.page != widget.page) {
  //     current = widget.page;
  //     controller.value = 0;
  //     controller.forward(from: 0);
  //     setState(() {});
  //   }
  //   super.didUpdateWidget(oldWidget);
  // }

  void jumpToPrevious() {
    if (current > 0) {
      current--;
      controller.value = 0;
      widget.onPageChanged(current);
    } else if (current == 0) {
      widget.onPageChanged(current - 1);
    }
    setState(() {});
  }

  void jumpToNext() {
    if (current >= widget.data.length - 1) {
      widget.onPageChanged(current + 1);
      return;
    }
    current++;
    widget.onPageChanged(current);
    if (mounted) setState(() {});
  }

  @override
  void dispose() {
    if (widget.animationController == null) controller.dispose();
    super.dispose();
  }
}
